==> ukui-search_4.10.5.0.orig.tar.gz: ukui-search-4.10.5.0/translations/ukui-search/zh_HK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>UkuiSearch::BestListWidget</name>
    <message>
        <location filename="../../frontend/view/best-list-view.cpp" line="389"/>
        <source>Best Matches</source>
        <translation>最佳匹配</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::CreateIndexAskDialog</name>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="42"/>
        <source>ukui-search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="71"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="78"/>
        <source>close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="96"/>
        <source>Creating index can help you get results more quickly. Would you like to create one?</source>
        <translation>創建索引可以快速獲取搜尋結果，是否創建？</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="107"/>
        <source>Don&apos;t remind me again</source>
        <translation>不再提醒</translation>
    </message>
    <message>
        <source>Don&apos;t remind</source>
        <translation type="vanished">不再提醒</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="118"/>
        <source>No</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="120"/>
        <source>Yes</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::MainWindow</name>
    <message>
        <location filename="../../frontend/mainwindow.cpp" line="73"/>
        <source>ukui-search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../../frontend/mainwindow.cpp" line="81"/>
        <source>Search Settings</source>
        <translation>設置搜索項</translation>
    </message>
    <message>
        <location filename="../../frontend/mainwindow.cpp" line="84"/>
        <source>Global Search</source>
        <translation>全域搜索</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::SearchLineEdit</name>
    <message>
        <location filename="../../frontend/control/search-line-edit.cpp" line="53"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::UkuiSearchGui</name>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="111"/>
        <source>Quit ukui-search application</source>
        <translation>退出搜索應用</translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="114"/>
        <source>Show main window</source>
        <translation>顯示主頁面</translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="117"/>
        <source>unregister a plugin with &lt;pluginName&gt;</source>
        <translation>使用 &lt;pluginName&gt;註銷外掛程式</translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="120"/>
        <source>register a plugin with &lt;pluginName&gt;</source>
        <translation>使用&lt;pluginName&gt;註冊外掛程式</translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="123"/>
        <source>move &lt;pluginName&gt; to the target pos</source>
        <translation>移動&lt;pluginName&gt;到目標位置</translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="126"/>
        <source>move plugin to &lt;index&gt;</source>
        <translation>將外掛程式移至&lt;index&gt;</translation>
    </message>
</context>
<context>
    <name>search</name>
    <message>
        <location filename="../../frontend/search-app-widget-plugin/provider/data/search.qml" line="115"/>
        <source>search</source>
        <translation>全域搜索</translation>
    </message>
</context>
</TS>

==> ukui-search_4.10.12.0.orig.tar.gz: ukui-search-4.10.12.0/translations/ukui-search/zh_HK.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>UkuiSearch::BestListWidget</name>
    <message>
        <location filename="../../frontend/view/best-list-view.cpp" line="408"/>
        <source>Best Matches</source>
        <translation>最佳匹配</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::CreateIndexAskDialog</name>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="42"/>
        <source>ukui-search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="71"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="78"/>
        <source>close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="96"/>
        <source>Creating index can help you get results more quickly. Would you like to create one?</source>
        <translation>創建索引可以快速獲取搜尋結果，是否創建？</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="107"/>
        <source>Don&apos;t remind me again</source>
        <translation>不再提醒</translation>
    </message>
    <message>
        <source>Don&apos;t remind</source>
        <translation type="vanished">不再提醒</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="118"/>
        <source>No</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="120"/>
        <source>Yes</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::MainWindow</name>
    <message>
        <location filename="../../frontend/mainwindow.cpp" line="73"/>
        <source>ukui-search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>Search Settings</source>
        <translation type="vanished">設置搜索項</translation>
    </message>
    <message>
        <source>Global Search</source>
        <translation type="vanished">全域搜索</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::SearchLineEdit</name>
    <message>
        <location filename="../../frontend/control/search-line-edit.cpp" line="53"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::UkuiSearchGui</name>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="111"/>
        <source>Quit ukui-search application</source>
        <translation>退出搜索應用</translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="114"/>
        <source>Show main window</source>
        <translation>顯示主頁面</translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="117"/>
        <source>unregister a plugin with &lt;pluginName&gt;</source>
        <translation>使用 &lt;pluginName&gt;註銷外掛程式</translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="120"/>
        <source>register a plugin with &lt;pluginName&gt;</source>
        <translation>使用&lt;pluginName&gt;註冊外掛程式</translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="123"/>
        <source>move &lt;pluginName&gt; to the target pos</source>
        <translation>移動&lt;pluginName&gt;到目標位置</translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="126"/>
        <source>move plugin to &lt;index&gt;</source>
        <translation>將外掛程式移至&lt;index&gt;</translation>
    </message>
</context>
<context>
    <name>search</name>
    <message>
        <location filename="../../frontend/search-app-widget-plugin/provider/data/search.qml" line="132"/>
        <source>search</source>
        <translation>全域搜索</translation>
    </message>
</context>
</TS>
